#
# spec file for package ghc-filepath-bytestring
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name filepath-bytestring
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.2.1.9
Release:        bp156.3.3
Summary:        Library for manipulating RawFilePaths in a cross platform way
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-filepath-devel
%endif

%description
This package provides functionality for manipulating 'RawFilePath' values.
It can be used as a drop in replacement for the filepath library to get the
benefits of using ByteStrings. It provides three modules:

* "System.FilePath.Posix.ByteString" manipulates POSIX/Linux style
'RawFilePath' values (with '/' as the path separator).

* "System.FilePath.Windows.ByteString" manipulates Windows style 'RawFilePath'
values (with either '\' or '/' as the path separator, and deals with drives).

* "System.FilePath.ByteString" is an alias for the module appropriate to your
platform.

All three modules provide the same API, and the same documentation (calling out
differences in the different variants).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.md TODO

%changelog
* Fri Dec  3 2021 Peter Simons <psimons@suse.com>
- Update filepath-bytestring to version 1.4.2.1.9.
  filepath-bytestring (1.4.2.1.9) unstable; urgency=medium
  * Relax bounds to allow base 4.16 (ghc 9.2).
  - - Joey Hess <id@joeyh.name>  Fri, 03 Dec 2021 11:49:58 -0400
* Thu Aug 12 2021 psimons@suse.com
- Update filepath-bytestring to version 1.4.2.1.8.
  filepath-bytestring (1.4.2.1.8) unstable; urgency=medium
  * Faster implementations of encodeFilePath and decodeFilePath.
    They are approximately 2x and 3x as fast, respectively.
  * encodeFilePath and decodeFilePath used to truncate at the first
    NUL. The new implementations do not do this. Since unix filepaths
    cannot contain NUL, this behavior change is can't cause any problems,
    unless the functions are used for values that are not actually
    valid filepaths.
  * Support cabal bench to benchmark the library.
  - - Joey Hess <id@joeyh.name>  Wed, 11 Aug 2021 12:17:15 -0400
* Thu Mar 18 2021 psimons@suse.com
- Update filepath-bytestring to version 1.4.2.1.7.
  filepath-bytestring (1.4.2.1.7) unstable; urgency=medium
  * Relax QuickCheck bounds to allow 2.14.
  * Relax base bounds so it will build with ghc 9.0.1.
  - - Joey Hess <id@joeyh.name>  Wed, 17 Mar 2021 08:11:27 -0400
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add filepath-bytestring at version 1.4.2.1.6.
